Changelog
=========

.. You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst

.. towncrier release notes start

1.0 (2019-05-09)
----------------

New features:


- Initial effort.
  Base code taken from `Products.CMFPlone` (created by @davisagli).
  Enhanced and packaged for more general Zope use.
  [dwt,jensens] (#1)


